Cheshire3 Objects: Document

|  | ## Cheshire3 Objects: Document

Description

A Document is the raw data which will become a record. It may be processed into a Record by a Parser, or into another Document type by a PreParser. Documents might be stored in a DocumentStore, if necessary, but can generally be discarded. Documents may be anything from a JPG file, to an unparsed XML file, to a string containing a URL. This allows for future compatability with new formats, as they may be incorporated into the system by implementing a Document type and a PreParser.

Implementations

- document.StringDocument
  Given a string, treat it as a document.

API

Function | Parameters | Returns | Description
--- | --- | --- | ---
__init__ | data, ?creator, ?history, ?mimeType |  | The constructer takes the data which should be used to construct the document. This is implementation dependant. It also optionally may take a creator object, process history information and a mimetype.
get_raw | session | data | Return the raw data for the document